# Xnano

Xnano is a Python library for building AI applications. It is designed to be simple, flexible, and extensible.

Xnano is the lightweight port of [zyx](https://zyx.hammad.fun)

## Features

- **Simple**: Xnano is designed to be simple to use and understand.
- **Flexible**: Xnano is designed to be flexible and extensible.
- **Extensible**: Xnano is designed to be extensible and easy to extend.

